@@ -1,9 +1,8 @@
 """Create a RequestModel to execute a Random corruption."""
 
-from typing import Dict
-
 from aidkitcli.core.analyses.random import random as request_factory
-from aidkitcli.data_access.analysis import post_analysis
+from aidkitcli.core.execute_analysis import execute_analysis
+from aidkitcli.core.report import Report
 
 
 def random(data: str,
@@ -15,7 +14,7 @@ def random(data: str,
            start_index: int = 0,
            perturbation_length: int = 100000,
            title: str = "Config Random Corruption"
-           ) -> Dict[str, int]:
+           ) -> Report:
     """
     Execute a Random Corruption and return a plot showing the performance of
     the model on the corrupted data.
@@ -53,4 +52,4 @@ def random(data: str,
         start_index=start_index,
         perturbation_length=perturbation_length,
     )
-    return post_analysis(request_model=request_model)
+    return execute_analysis(request_model=request_model)
