@@ -15,6 +15,7 @@ def fgsm(data: str,
          ascend: bool = True,
          mask: List[int] = [],
          step_length: List[int] = [],
+         target_output: int = 0,
          title="Config FGSM Attack"
          ) -> RequestModel:
     """
@@ -39,12 +40,14 @@ def fgsm(data: str,
 
     If the task of the attacked model is regression, the perturbation tries to
     increase or decrease - depending on the value of ascend - the value of the
-    output node (the loss). If the task is classification the perturbation
+    output node (the loss). For multiregression models, it tries to increase
+    or decrease the value of the output node whose index is given by
+    target_output. If the task is classification, the perturbation
     tries to decrease the probability value of the original prediction.
 
     Currently, this attack strategy can be applied to:
 
-    - Keras regression recurrent models
+    - Keras (multi-)regression recurrent models
     - Keras classification feedforward models
     - scikit-learn classification feedforward models
 
@@ -63,6 +66,8 @@ def fgsm(data: str,
         variables
     :param step_length: number of time steps with constant value before next
         increase or decrease
+    :param target_output: the index of the output neuron the algorithm tries
+                          to modify (only relevant for multiregression models)
     :param title: title of the configuration (default: "Config FGSM Attack")
     :return: a RequestModel instance containing all the information needed to
         execute an FGSM Attack
@@ -80,6 +85,7 @@ def fgsm(data: str,
             "ascend": ascend,
             "mask": mask,
             "step_length": step_length,
+            "target_output": target_output,
             "saver": 1
         }}
     )
